using System;
using System.Data;
using System.Windows.Forms;
using Syncfusion.Windows.Forms.Grid;

namespace WindowsApplication27
{
	/// <summary>
	/// Tda pomocnch statickch metod pro prci s Syncfusion objekty.
	/// </summary>
	public class SFUtils {
		/// <summary>
		/// Vrt hodnotu zadanho sloupce v parent zznamu aktulnho zznamu.
		/// </summary>
		/// <param name="grid">Grid.</param>
		/// <param name="colName">Nzev sloupce, ze kterho m bt vrcena hodnota.</param>
		/// <returns>Hodnotu jako typ objekt.</returns>
		public static Object GetCurrentParentGridRowColumn(GridDataBoundGrid grid, string colName){
			Object ret = null;

			int ri = grid.CurrentCell.RowIndex;
			GridBoundRecordState recordState = grid.Binder.GetRecordStateAtRowIndex(ri);
			if(recordState != null){
				if (recordState.LevelIndex > 0) {
					recordState = recordState.Parent;
				}
				ret = GetColumnFromRecordState(recordState, colName);
			}else{
//				throw new NoGridItemSelectedException();
			}

			return ret;		
		}				

		/// <summary>
		/// Vrt hodnotu zadanho sloupce v gridu na aktulnm dku.
		/// </summary>
		/// <param name="grid">Grid.</param>
		/// <param name="colName">Nzev sloupce, ze kterho m bt vrcena hodnota.</param>
		/// <returns>Hodnotu jako typ objekt.</returns>
		public static Object GetCurrentGridRowColumn(GridDataBoundGrid grid, string colName, int levelIndex){
			Object ret = null;

			int ri = grid.CurrentCell.RowIndex;
			GridBoundRecordState recordState = grid.Binder.GetRecordStateAtRowIndex(ri);
			if(recordState != null && recordState.LevelIndex == levelIndex){
				ret = GetColumnFromRecordState(recordState, colName);
			}else{
//				throw new NoGridItemSelectedException();
			}

			return ret;		
		}				

		public static Object GetCurrentGridRowColumn(GridDataBoundGrid grid, string colName){
			return GetCurrentGridRowColumn(grid, colName, 0);		
		}				

		public static Object GetColumnFromRecordState(GridBoundRecordState recordState, string colName){
			DataRowView drv = recordState.ListManager.Current as DataRowView;
			if(drv == null){
//				throw new NoGridItemSelectedException();
			}

			return drv[colName];
		}
		
		/// <summary>
		/// Vrt hodnotu celho dku v gridu na aktulnm dku.
		/// </summary>
		/// <param name="grid">grid</param>
		/// <param name="levelIndex">level index gridu</param>
		/// <returns>hodnota jako DataRowView</returns>
		public static DataRowView GetCurrentGridRow(GridDataBoundGrid grid, int levelIndex)
		{
			DataRowView drv = null;

			int ri = grid.CurrentCell.RowIndex;
			GridBoundRecordState recordState = grid.Binder.GetRecordStateAtRowIndex(ri);
			if(recordState != null && recordState.LevelIndex == levelIndex)
			{
				drv = recordState.ListManager.Current as DataRowView;
				
			}
			else
			{
//				throw new NoGridItemSelectedException();
			}

			return drv;		
		}				
		
		/// <summary>
		/// Vrt hodnotu celho dku v gridu na aktulnm dku.
		/// </summary>
		/// <param name="grid">grid</param>
		public static DataRowView GetCurrentGridRow(GridDataBoundGrid grid)
		{
		
			return GetCurrentGridRow(grid,0);
		}

		//		/// <summary>
//		/// Vrt hodnotu zadanho sloupce v gridu na aktulnm dku.
//		/// </summary>
//		/// <param name="f">Formul.</param>
//		/// <param name="grid">Grid.</param>
//		/// <param name="colName">Nzev sloupce, ze kterho m bt vrcena hodnota.</param>
//		/// <returns>Hodnotu jako typ objekt.</returns>
//		public static Object GetCurrentGridRowColumn(Form f, GridDataBoundGrid grid, string colName){
//			if(f.BindingContext[grid.DataSource, grid.DataMember].Count == 0) {
//				throw new NoGridItemSelectedException();
//			}			
//
//			Object o = f.BindingContext[grid.DataSource, grid.DataMember].Current;
//			DataRowView drv = (DataRowView)o;
//
//			return drv[colName];		
//		}		
		
		/// <summary>
		/// Nastav aktuln dek v gridu na pozici kurzoru.
		/// </summary>
		/// <param name="grid">Grid, ve kterm se m nastavit dek.</param>
		public static void SetCurrentRowToMouseCursor(GridDataBoundGrid grid)
		{
			SetCurrentRowToMouseCursor(grid, 1);
		}
		
		/// <summary>
		/// Nastav aktuln dek v gridu na pozici kurzoru.
		/// </summary>
		/// <param name="grid">Grid, ve kterm se m nastavit dek.</param>
		public static void SetCurrentRowToMouseCursor(GridDataBoundGrid grid, int headerRowCount){
			int rowIndex = 0, colIndex = 0;
			if(grid.PointToRowCol(grid.PointToClient(Cursor.Position), out rowIndex, out colIndex)){
				//grid.Binder.SetCurrentPosition(rowIndex - headerRowCount, true);
				grid.CurrentCell.MoveTo(rowIndex, 0, GridSetCurrentCellOptions.ScrollInView|GridSetCurrentCellOptions.NoActivate|GridSetCurrentCellOptions.NoSetFocus|GridSetCurrentCellOptions.NoSelectRange);
				//int pos = grid.Binder.RowIndexToListManagerPosition(grid.CurrentCell.RowIndex);
				grid.Binder.SetCurrentPosition(rowIndex - headerRowCount, true);
			}
		}
		public static void SetCurrentRowOnKeyPress(GridDataBoundGrid grid,Keys keyCode){
			
			SetCurrentRowOnKeyPress(grid,keyCode,1);

		}
		/// <summary>
		/// Pohyb po dcch v gridu pomoc kurzorovch klves pokud m grid
		/// nastaveno Enabled =false (slou pouze pro zobrazen)
		/// pozice je nastavena nastavenm binderu gridu na dal nebo pedchoz zznam
		/// </summary>
		public static void SetCurrentRowOnKeyPress(GridDataBoundGrid grid,Keys keyCode,int headerRowCount){
			
			if (grid.Binder.RecordCount>0)
			{
				int nextRowIndex;
				if(keyCode == Keys.Down)
				{	
					nextRowIndex=grid.CurrentCell.RowIndex+1;

					grid.CurrentCell.MoveTo(nextRowIndex, 0, GridSetCurrentCellOptions.ScrollInView|GridSetCurrentCellOptions.NoActivate|GridSetCurrentCellOptions.NoSetFocus|GridSetCurrentCellOptions.NoSelectRange);
					grid.Binder.SetCurrentPosition(nextRowIndex - headerRowCount, true);				
				}
				if(keyCode == Keys.Up)
				{
					nextRowIndex=grid.CurrentCell.RowIndex-1;

					grid.CurrentCell.MoveTo(nextRowIndex, 0, GridSetCurrentCellOptions.ScrollInView|GridSetCurrentCellOptions.NoActivate|GridSetCurrentCellOptions.NoSetFocus|GridSetCurrentCellOptions.NoSelectRange);
					grid.Binder.SetCurrentPosition(nextRowIndex - headerRowCount, true);				

				}
				if(keyCode == Keys.PageDown)
				{
					nextRowIndex=grid.CurrentCell.RowIndex+10;
					
					if (nextRowIndex>grid.Model.RowCount)
					{
						nextRowIndex=grid.Model.RowCount;
					}
					

					grid.CurrentCell.MoveTo(nextRowIndex, 0, GridSetCurrentCellOptions.ScrollInView|GridSetCurrentCellOptions.NoActivate|GridSetCurrentCellOptions.NoSetFocus|GridSetCurrentCellOptions.NoSelectRange);
					grid.Binder.SetCurrentPosition(nextRowIndex - headerRowCount, true);				
				
				
				}
				if(keyCode == Keys.PageUp)
				{
					nextRowIndex=grid.CurrentCell.RowIndex-10;
					
					if (nextRowIndex<0)
					{
						nextRowIndex=headerRowCount;
					}

					grid.CurrentCell.MoveTo(nextRowIndex, 0, GridSetCurrentCellOptions.ScrollInView|GridSetCurrentCellOptions.NoActivate|GridSetCurrentCellOptions.NoSetFocus|GridSetCurrentCellOptions.NoSelectRange);
					grid.Binder.SetCurrentPosition(nextRowIndex - headerRowCount, true);				

				}
			}
		
		}
		/// <summary>
		/// Vrti masku pro datum ve formtu (nap. ##/##/#### nebo ####/##/## dle nastaven CurrentCulture)
		/// </summary>
		/// <returns></returns>
		public static string GetCurrentCultureDateMask(){

			string separator =System.Threading.Thread.CurrentThread.CurrentCulture.DateTimeFormat.DateSeparator;

			string shortDatePattern = System.Threading.Thread.CurrentThread.CurrentCulture.DateTimeFormat.ShortDatePattern;
			
			// zajm m, kde je v datumu umstn rok, proto datum rozsekm dle oddlovae
			// a zjituju, kter st datumu je vt ne 2 znaky
			// pro den i msc nastavuji formt na ## i kdy currentCulture teba povoluje 
			// zadn 01 i 1 
			int sepIndex;
			string[] partOfDate = new string[3];
			
			// najdu 1 oddlova v datumu
			sepIndex = shortDatePattern.IndexOf(separator);
			
			partOfDate[0] = shortDatePattern.Substring(0,sepIndex);

			shortDatePattern= shortDatePattern.Remove(0,sepIndex+1);

			// najdu 2 oddlova v datumu
			sepIndex = shortDatePattern.IndexOf(separator);
			
			partOfDate[1] = shortDatePattern.Substring(0,sepIndex);

			shortDatePattern= shortDatePattern.Remove(0,sepIndex+1);


			// zbytek datumu
			partOfDate[2] = shortDatePattern.Substring(0);


			// nyn slom masku
			string mask	="";

			foreach(string s in partOfDate)
			{
			
				if(s.Length>2) // jde o rok
					mask+="/####";
				else // jde o den nebo msc
					mask+="/##";
			}
			
			if (mask!="")
			{
				mask=mask.Remove(0,1);
			}

			return 	mask;
		
		}


		/// <summary>
		/// Hled dan etzec v gridu, pokud ho najde natav se na tento zznam a 
		/// vrac hodnotu true, pokud ne vrac false
		/// </summary>
		/// <param name="value">hledan etzec</param>
		/// <param name="grid">grid ve kterm hledm</param>
		/// <returns></returns>
		public static bool FindRecordInGrid(string value,int iColumn,Syncfusion.Windows.Forms.Grid.GridDataBoundGrid grid)
		{
			GridFindReplaceDialogSink fr = new GridFindReplaceDialogSink(grid);
			GridFindReplaceEventArgs fre;
			object frLocationInfo = null;
			
			frLocationInfo = GridRangeInfo.Cell(grid.Model.RowCount, iColumn);

			//GridFindTextOptions.ColumnOnly|
			fre = new GridFindReplaceEventArgs(value,"",GridFindTextOptions.WholeTable| GridFindTextOptions.SearchUp  |GridFindTextOptions.MatchWholeCell ,frLocationInfo);

			bool found = false;
			if (fr.Find(fre)!=null)
			{
			
				found = true;
			}
			return found;
		}


//		public static Object GetCurrentGridRowColumn(Form f, GridDataBoundGrid grid, string colName){
//			if(f.BindingContext[grid.DataSource].Count == 0) {
//				throw new NoGridItemSelectedException();
//			}			
//
//			GridStyleInfo gsi = grid[grid.CurrentCell.RowIndex, grid.Model.NameToColIndex(colName)];
//
//			return gsi.CellValue;
//		}
	}
}
